"use strict";
/* eslint-disable tsdoc/syntax,jsdoc/require-description */
/**
 * {@link TCPTransport TCP-based transport} for {@link Network}, can discover and automatically
 * establish encrypted connections over TCP.
 *
 * Supports pluggable discoveries via {@link TCPPeerDiscovery} with a mDNS
 * implementation in {@link TCPPeerMDNSDiscovery} that discover peers on the
 * same local network.
 *
 * ```javascript
 * import { Network, AnonymousAuth } from 'ataraxia';
 * import { TCPTransport, TCPPeerMDNSDiscovery } from 'ataraxia-tcp';
 *
 * // Setup a network with anonymous authentication
 * const net = new Network({
 *   name: 'name-of-your-app-or-network',
 *   transports: [
 *     new TCPTransport({
 *       // Discover other peers on the same physical network
 *       discovery: new TCPPeerMDNSDiscovery(),
 *       // Use anonymous authentication
 *       authentication: [
 *         new AnonymousAuth()
 *       ]
 *     })
 *   ]
 * });
 *
 * // Start the network
 * await net.start();
 * ```
 *
 * @module ataraxia-tcp
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
__exportStar(require("./TCPPeerDiscovery"), exports);
__exportStar(require("./TCPPeerMDNSDiscovery"), exports);
__exportStar(require("./TCPTransport"), exports);
//# sourceMappingURL=index.js.map